@@ -1,6 +1,7 @@
 """Pipeline for ZeroDose project."""
 from .abnormality import create_abnormality_maps
-from .full import run_full
+from .full import run_with_registration
+from .main import run
 from .niftyreg import from_mni
 from .niftyreg import to_mni
 from .normalization import normalize_to_pet
@@ -9,7 +10,8 @@ from .synthetization import synthesize_baselines
 
 __all__ = [
     "create_abnormality_maps",
-    "run_full",
+    "run",
+    "run_with_registration",
     "from_mni",
     "to_mni",
     "normalize_to_pet",
